﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using Infragistics.Windows;
using Infragistics.Windows.DataPresenter;


namespace MyDataGrid
{
    public class AwrdsDataGrid : XamDataGrid
    {
        Label lblFilteredItems = new Label();

        public AwrdsDataGrid()
        {
            this.Loaded += new RoutedEventHandler(myGrid_Loaded);
            this.RecordsInViewChanged += new EventHandler<Infragistics.Windows.DataPresenter.Events.RecordsInViewChangedEventArgs>(myGrid_RecordsInViewChanged);
        }
        
        #region Events

        void myGrid_Loaded(object sender, RoutedEventArgs e)
        {
            XamDataGrid myDataGrid = sender as XamDataGrid;
            Grid grid = Utilities.GetDescendantFromType(myDataGrid, typeof(Grid), false) as Grid;

            if (grid != null && myDataGrid.Records.Count > 0)
            {
                grid.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) });

                Grid DynamicGrid = new Grid();
                DynamicGrid.HorizontalAlignment = HorizontalAlignment.Stretch;
                DynamicGrid.VerticalAlignment = VerticalAlignment.Top;

                RowDefinition gridRow1 = new RowDefinition { Height = new GridLength(1, GridUnitType.Star) };
                RowDefinition gridRow2 = new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) };
                DynamicGrid.RowDefinitions.Add(gridRow1);
                DynamicGrid.RowDefinitions.Add(gridRow2);

                Grid.SetRow(lblFilteredItems, 0);
                DynamicGrid.Children.Add(lblFilteredItems);

                SearchBar searchBar = new SearchBar();
                Grid.SetRow(searchBar, 1);
                DynamicGrid.Children.Add(searchBar);

                grid.Children.Add(DynamicGrid);
            }
            else
            {
                grid.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Star) });
                lblFilteredItems.Visibility = Visibility.Visible;
                lblFilteredItems.Content = "Please Select A Search Criteria";
                lblFilteredItems.VerticalAlignment = VerticalAlignment.Bottom;
                lblFilteredItems.HorizontalAlignment = HorizontalAlignment.Center;
                Grid.SetRow(lblFilteredItems, 0);
                grid.Children.Add(lblFilteredItems);
            }

        }

        void myGrid_RecordsInViewChanged(object sender, Infragistics.Windows.DataPresenter.Events.RecordsInViewChangedEventArgs e)
        {
            string results = string.Empty;
            XamDataGrid myDataGrid = sender as XamDataGrid;

            if (myDataGrid.Records.Count > 0)
            {
                foreach (RecordFilter filter in myDataGrid.FieldLayouts[0].RecordFilters)
                {
                    if (filter.Conditions.Count > 0)
                    {
                        results += filter.FieldName + ",";
                    }
                }
                lblFilteredItems.Content = "Filtered Fields: " + results;
                lblFilteredItems.VerticalAlignment = VerticalAlignment.Bottom;
                lblFilteredItems.HorizontalAlignment = HorizontalAlignment.Left;
            }
            else
            {
                SearchBar searchBar = new SearchBar();
                lblFilteredItems.Visibility = Visibility.Visible;
                lblFilteredItems.Content = "No Data Found";
                lblFilteredItems.VerticalAlignment = VerticalAlignment.Center;
                lblFilteredItems.HorizontalAlignment = HorizontalAlignment.Center;
                searchBar.Visibility = Visibility.Collapsed;
            }
        }
        #endregion
    }
}
